==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>指示器樣式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>經典</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>經典</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>居中</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>壹直顯示</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>壹直隱藏</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>智能隱藏</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>任務欄設置</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>指示器樣式</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>經典模式</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>居中模式</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>壹直顯示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>壹直隱藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智能隱藏</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>任務欄設置</translation>
    </message>
</context>
</TS>
